package com.ruoyi.mall.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.mall.domain.Bo.CheckingOutParamBo;
import com.ruoyi.mall.domain.Bo.SchoolMajorLinkBO;
import com.ruoyi.mall.domain.MallLinkMajorSchool;
import com.ruoyi.mall.domain.MallSchoolBatchLink;
import com.ruoyi.mall.domain.Vo.MajorItemVo;

/**
 * 专业与学校关联Service接口
 *
 * @author Lsm
 * @date 2023-10-23
 */
public interface IMallLinkMajorSchoolService
{
    /**
     * 查询专业与学校关联
     *
     * @param linkId 专业与学校关联主键
     * @return 专业与学校关联
     */
    public MallLinkMajorSchool selectMallLinkMajorSchoolByLinkId(Long linkId);

    /**
     * 查询专业与学校关联列表
     *
     * @param mallLinkMajorSchool 专业与学校关联
     * @return 专业与学校关联集合
     */
    public List<MallLinkMajorSchool> selectMallLinkMajorSchoolList(MallLinkMajorSchool mallLinkMajorSchool);

    /**
     * 新增专业与学校关联
     *
     * @param mallLinkMajorSchool 专业与学校关联
     * @return 结果
     */
    public AjaxResult insertMallLinkMajorSchool(MallLinkMajorSchool mallLinkMajorSchool);

    /**
     * 修改专业与学校关联
     *
     * @param mallLinkMajorSchool 专业与学校关联
     * @return 结果
     */
    public AjaxResult updateMallLinkMajorSchool(MallLinkMajorSchool mallLinkMajorSchool);

    /**
     * 批量删除专业与学校关联
     *
     * @param linkIds 需要删除的专业与学校关联主键集合
     * @return 结果
     */
    public int deleteMallLinkMajorSchoolByLinkIds(Long[] linkIds);

    /**
     * 删除专业与学校关联信息
     *
     * @param linkId 专业与学校关联主键
     * @return 结果
     */
    public int deleteMallLinkMajorSchoolByLinkId(Long linkId);

    /** 志愿添加 在筛选学校基础上 筛选专业*/
    public List<MajorItemVo> astrictMajorItemList(CheckingOutParamBo bo);

    /**
     * 查询专业与学校关联表重复列表
     *
     * @return 学校集合
     */
    public List<MallLinkMajorSchool> selectMallLinkMajorSchoolRepetitionList();

    /**
     * 关联数据与学校专业表
     * @return
     */
    public int linkAccept();

    /** 招生计划 */
    public int linkAcceptPlan();

    /**
     * 导出学校数据
     * @return
     */
    public List<SchoolMajorLinkBO> getAllSchoolAndMajorList();

    /**
     * 硕士点数
     */
    public void getSchool();

    /**
     * 新招处理
     */
    public void newSchool();
}
